
import { Phone } from "lucide-react";
import { Card } from "@/components/ui/card";

interface PhoneNumber {
  id: string;
  number: string;
  status: "active" | "inactive";
}

const mockNumbers: PhoneNumber[] = [
  { id: "1", number: "+1 (555) 123-4567", status: "active" },
  { id: "2", number: "+1 (555) 234-5678", status: "active" },
];

export function PhoneNumberList() {
  return (
    <div className="space-y-4 p-4 animate-fadeIn">
      <div className="flex items-center justify-between mb-6">
        <h2 className="text-2xl font-semibold tracking-tight">Phone Numbers</h2>
        <span className="text-sm text-muted-foreground">
          {mockNumbers.length} numbers
        </span>
      </div>
      <div className="grid gap-4">
        {mockNumbers.map((number) => (
          <Card
            key={number.id}
            className="p-4 transition-all hover:shadow-md cursor-pointer group"
          >
            <div className="flex items-center space-x-4">
              <div className="h-10 w-10 rounded-full bg-secondary flex items-center justify-center group-hover:bg-primary group-hover:text-white transition-colors">
                <Phone className="h-5 w-5" />
              </div>
              <div className="flex-1">
                <h3 className="font-medium">{number.number}</h3>
                <p className="text-sm text-muted-foreground">
                  Status:{" "}
                  <span
                    className={
                      number.status === "active"
                        ? "text-green-500"
                        : "text-red-500"
                    }
                  >
                    {number.status}
                  </span>
                </p>
              </div>
            </div>
          </Card>
        ))}
      </div>
    </div>
  );
}
